@@ -16,7 +16,7 @@ use http::header;
 use hyper::{Body, Request, Response, StatusCode};
 use std::collections::HashSet;
 
-use crate::{error_page, handler::RequestHandlerOpts, Error};
+use crate::{Error, error_page, handler::RequestHandlerOpts};
 
 /// It defines CORS instance.
 #[derive(Clone, Debug)]
@@ -72,11 +72,11 @@ pub fn new(
 
         if cors_res.is_some() {
             tracing::info!(
-                    "cors enabled=true, allow_methods=[GET,HEAD,OPTIONS], allow_origins={}, allow_headers=[{}], expose_headers=[{}]",
-                    origins_str,
-                    allow_headers_str,
-                    expose_headers_str,
-                );
+                "cors enabled=true, allow_methods=[GET,HEAD,OPTIONS], allow_origins={}, allow_headers=[{}], expose_headers=[{}]",
+                origins_str,
+                allow_headers_str,
+                expose_headers_str,
+            );
         }
         cors_res
     };
@@ -233,10 +233,11 @@ pub enum Validated {
     NotCors,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 /// Forbidden errors.
 pub enum Forbidden {
     /// Forbidden error origin.
+    #[default]
     Origin,
     /// Forbidden error method.
     Method,
@@ -244,12 +245,6 @@ pub enum Forbidden {
     Header,
 }
 
-impl Default for Forbidden {
-    fn default() -> Self {
-        Self::Origin
-    }
-}
-
 impl Configured {
     /// Check for the incoming CORS request.
     pub fn check_request(
@@ -292,7 +287,8 @@ impl Configured {
                         let h = header.trim();
                         if !self.is_header_allowed(h) {
                             tracing::error!(
-                                "cors: header `{}` is not allowed because is missing in `cors_allow_headers` server option", h
+                                "cors: header `{}` is not allowed because is missing in `cors_allow_headers` server option",
+                                h
                             );
                             return Err(Forbidden::Header);
                         }
@@ -442,8 +438,8 @@ pub(crate) fn post_process<T>(
 
 #[cfg(test)]
 mod tests {
-    use super::{post_process, pre_process, Configured, Cors};
-    use crate::{handler::RequestHandlerOpts, Error};
+    use super::{Configured, Cors, post_process, pre_process};
+    use crate::{Error, handler::RequestHandlerOpts};
     use hyper::{Body, Request, Response, StatusCode};
 
     fn make_request(method: &str, origin: &str) -> Request<Body> {
