@@ -517,6 +517,18 @@ pub struct General {
     /// Prevent following files or directories if any path name component is a symbolic link.
     pub disable_symlinks: bool,
 
+    #[arg(
+        long,
+        default_value = "false",
+        default_missing_value("true"),
+        num_args(0..=1),
+        require_equals(false),
+        action = clap::ArgAction::Set,
+        env = "SERVER_ACCEPT_MARKDOWN",
+    )]
+    /// Enable markdown content negotiation. When a client sends Accept: text/markdown, serve .md or .html.md files if available.
+    pub accept_markdown: bool,
+
     #[arg(
         long,
         default_value = "false",
